@@ -1,17 +1,37 @@
 import numpy as np
 from . import ReadData as data
-import re
 from sympy import *
 
-def ElasticConstants(stresses,strains):
+def finitediff(C,strains):
+	deriv = []
+	signchange = []
+	inflection = []
+	for i in range(len(C) - 1):
+		d = (C[i + 1] - C[i]) / (strains[i + 1] - strains[i])
+		deriv.append(d)
+		if i != 0:
+			check = np.sign(deriv[i]-deriv[i-1])
+			signchange.append(check)
+			if len(signchange) != 1:
+				if (signchange[-2] != signchange[-1]):
+					inflection.append(C[i])
+	inflection = inflection[:-1]
+	if not d:
+		C_mid = 0
+	else:
+		C_mid = (inflection[0] + inflection[1]) / 2
+	#print(C_mid)
+	return C_mid
 
+
+def ElasticConstants(stresses,strains):
 	stresses = data.ReadElastic(stresses)
 	strains = data.ReadElastic(strains)
 	
 	stresses = stresses.get_tensor()
 	strains = strains.get_tensor()
 
-	stresses = stresses * 2 # Ha to Ry
+	stresses = stresses * 2 #Ha to Ry
 
 	C11, C12, C13, C14, C15, C16 = symbols('C11 C12 C13 C14 C15 C16')
 	C22, C23, C24, C25, C26 = symbols('C22 C23 C24 C25 C26')
@@ -320,19 +340,22 @@ def ElasticConstants(stresses,strains):
 		tmp2 = new_strain[i,:]
 		e_vec = np.append(e_vec,tmp2)
 		if np.mod(i+1,3) == 0:
-		#Test for which strain is being applied
-		#important : determines which C values to evaluate
-		#STRAINS 1 - 6   ->> Triclinic   ; all 6 applied
-		#STRAIN  7       ->> Cubic       ; 2 applied (3 and 4+5+6)
 
-		#strain No  tag1 tag2
-		# 1	 0   2
-		# 2	 2   2
-		# 3	 4   2
-		# 4	 2   4
-		# 5	 4   4
-		# 6	 6   4
-		# 7	 12  12
+			"""
+			Test for which strain is being applied
+			important : determines which C values to evaluate
+			STRAINS 1 - 6   ->> Triclinic   ; all 6 applied
+			STRAIN  7       ->> Cubic       ; 2 applied (3 and 4+5+6)
+	
+			strain No  tag1 tag2
+			 1	 0   2
+			 2	 2   2
+			 3	 4   2
+			 4	 2   4
+			 5	 4   4
+			 6	 6   4
+			 7	 12  12
+			"""
 
 			e_vec = np.reshape(e_vec,(3,3))
 			t_vec = np.reshape(t_vec,(3,3))
@@ -372,7 +395,6 @@ def ElasticConstants(stresses,strains):
 				eqs = EC_matrix.multiply(e_vec)
 				eqs = eqs - t_vec 
 				ans = solve([eqs[0], eqs[1], eqs[2], eqs[3], eqs[4], eqs[5]], [C12, C22, C23, C24, C25, C26])
-				C12_.append(ans[C12])
 				C22_.append(ans[C22])
 				C23_.append(ans[C23])
 				C24_.append(ans[C24])
@@ -390,8 +412,6 @@ def ElasticConstants(stresses,strains):
 				eqs = EC_matrix.multiply(e_vec)
 				eqs = eqs - t_vec 
 				ans = solve([eqs[0], eqs[1], eqs[2], eqs[3], eqs[4], eqs[5]], [C13, C23, C33, C34, C35, C36])
-				C13_.append(ans[C13])
-				C23_.append(ans[C23])
 				C33_.append(ans[C33])
 				C34_.append(ans[C34])
 				C35_.append(ans[C35])
@@ -408,11 +428,6 @@ def ElasticConstants(stresses,strains):
 				eqs = EC_matrix.multiply(e_vec)
 				eqs = eqs - t_vec
 				ans = solve([eqs[0], eqs[1], eqs[2], eqs[3], eqs[4], eqs[5]], [C16, C26, C36, C46, C56, C66])
-				C16_.append(ans[C16])
-				C26_.append(ans[C26])
-				C36_.append(ans[C36])
-				C46_.append(ans[C46])
-				C56_.append(ans[C56])
 				C66_.append(ans[C66])
 				t_vec = []
 				e_vec = []
@@ -426,10 +441,6 @@ def ElasticConstants(stresses,strains):
 				eqs = EC_matrix.multiply(e_vec)
 				eqs = eqs - t_vec
 				ans = solve([eqs[0], eqs[1], eqs[2], eqs[3], eqs[4], eqs[5]], [C15, C25, C35, C45, C55, C56])
-				C15_.append(ans[C15])
-				C25_.append(ans[C25])
-				C35_.append(ans[C35])
-				C45_.append(ans[C45])
 				C55_.append(ans[C55])
 				C56_.append(ans[C56])
 				t_vec = []
@@ -444,9 +455,6 @@ def ElasticConstants(stresses,strains):
 				eqs = EC_matrix.multiply(e_vec)
 				eqs = eqs - t_vec
 				ans = solve([eqs[0], eqs[1], eqs[2], eqs[3], eqs[4], eqs[5]], [C14, C24, C34, C44, C45, C46])
-				C14_.append(ans[C14])
-				C24_.append(ans[C24])
-				C34_.append(ans[C34])
 				C44_.append(ans[C44])
 				C45_.append(ans[C45])
 				C46_.append(ans[C46])
@@ -518,42 +526,35 @@ def ElasticConstants(stresses,strains):
 			
 	
 
-	#Inflection Points -- EQ Elastic Constant at 0 strain
-	#Strain1
-	C11 = (max(C11_) + min(C11_)) / 2
-	C12 = (max(C12_) + min(C12_)) / 2
-	C13 = (max(C13_) + min(C13_)) / 2
-	C14 = (max(C14_) + min(C14_)) / 2
-	C15 = (max(C15_) + min(C15_)) / 2
-	C16 = (max(C16_) + min(C16_)) / 2
+	C11 = finitediff(C11_,e_range)
+	C12 = finitediff(C12_,e_range)
+	C13 = finitediff(C13_,e_range)
+	C14 = finitediff(C14_,e_range)
+	C15 = finitediff(C15_,e_range)
+	C16 = finitediff(C16_,e_range)
 
-	#Strain2
-	C22 = (max(C22_) + min(C22_)) / 2
-	C23 = (max(C23_) + min(C23_)) / 2
-	C24 = (max(C24_) + min(C24_)) / 2
-	C25 = (max(C25_) + min(C25_)) / 2
-	C26 = (max(C26_) + min(C26_)) / 2
+	C22 = finitediff(C22_,e_range)
+	C23 = finitediff(C23_,e_range)
+	C24 = finitediff(C24_,e_range)
+	C25 = finitediff(C25_,e_range)
+	C26 = finitediff(C26_,e_range)
 
-	#Strain3
-	C33 = (max(C33_) + min(C33_)) / 2
-	C34 = (max(C34_) + min(C34_)) / 2
-	C35 = (max(C35_) + min(C35_)) / 2
-	C36 = (max(C36_) + min(C36_)) / 2
+	C33 = finitediff(C33_,e_range)
+	C34 = finitediff(C34_,e_range)
+	C35 = finitediff(C35_,e_range)
+	C36 = finitediff(C36_,e_range)
 
-	#Strain4
-	C66 = (max(C66_) + min(C66_)) / 2
+	C66 = finitediff(C66_,e_range)
 
-	#Strain5
-	C55 = (max(C55_) + min(C55_)) / 2
-	C56 = (max(C56_) + min(C56_)) / 2
+	C55 = finitediff(C55_,e_range)
+	C56 = finitediff(C56_,e_range)
 
-	#Strain6
-	C44 = (max(C44_) + min(C44_)) / 2
-	C45 = (max(C45_) + min(C45_)) / 2
-	C46 = (max(C46_) + min(C46_)) / 2
+	C44 = finitediff(C44_,e_range)
+	C45 = finitediff(C45_,e_range)
+	C46 = finitediff(C46_,e_range)
 
 
 	EC_matrix = np.array([[C11, C12, C13, C14, C15, C16],[C12, C22, C23, C24, C25, C26], [C13, C23, C33, C34, C35, C36],[C14, C24, C34, C44, C45, C46],[C15, C25, C35, C45, C55, C56],[C16, C26, C36, C46, C56, C66]])
-	EC_matrix = -(EC_matrix)
+	EC_matrix = -(EC_matrix) #Hooke's Law
 
 	return EC_matrix
