@@ -62,20 +62,11 @@ class Control:
 			SSFreqFile = XtalPath + self.xtal + x + '.ss.yaml'
 			RefFreqFile = XtalPath + self.xtal + x + '.ref.yaml'
 			ShiftFreqFile = XtalPath + self.xtal + x + '.shift.yaml'
-			StrainFile = XtalPath + self.xtal + '.strains'
-			StressFile = XtalPath + self.xtal + x + '.stresses'
 
 			SSFreqFileOut = SubDir + os.path.sep + self.xtal + x + '.ss.yaml'
 			RefFreqFileOut = SubDir + os.path.sep + self.xtal + x + '.ref.yaml'
 			ShiftFreqFileOut = SubDir + os.path.sep + self.xtal + x + '.shift.yaml'
-			StrainFileOut = SubDir + os.path.sep + self.xtal + '.strains'
-			StressFileOut = SubDir + os.path.sep + self.xtal + x + '.stresses'
 
-			try:
-				copyfile(StrainFile,StrainFileOut)
-			except OSError as e:
-				print('Cannot Find file %s' % e)
-				continue
 			try:
 				os.rename(SSFreqFile, SSFreqFileOut)
 			except FileExistsError:
@@ -94,23 +85,26 @@ class Control:
 				os.remove(ShiftFreqFileOut)
 				os.rename(ShiftFreqFile, ShiftFreqFileOut)
 
-			try:
-				os.rename(StressFile, StressFileOut)
-			except FileExistsError:
-				os.remove(StressFileOut)
-				os.rename(StressFile, StressFileOut)
-
 	def SolveECs(self):
 		print("Solving ", self.xtal, " Elastic Constants...")
-		CurrentDir = os.getcwd() #+ os.path.sep + 'datafiles'
+		CurrentDir = os.getcwd()
 		XtalPath = CurrentDir + os.path.sep + self.xtal + os.path.sep
 		AllConstants = []
 		for x in range(self.count):
 			x = str(x + 1)
 			SubDir = XtalPath + x
-			StrainFile = SubDir + os.path.sep + self.xtal + '.strains'
-			StressFile = SubDir + os.path.sep + self.xtal + x + '.stresses'
-			EC_Matrix = ECs.ElasticConstants(StressFile,StrainFile)
+
+			StrainFile = XtalPath + self.xtal + '.strains'
+			StressFile = XtalPath + self.xtal + x + '.stresses'
+			StressFileOut = SubDir + os.path.sep + self.xtal + x + '.stresses'
+
+			try:
+				os.rename(StressFile,StressFileOut)
+			except FileExistsError:
+				os.remove(StressFileOut)
+				os.rename(StressFile,StressFileOut)
+
+			EC_Matrix = ECs.ElasticConstants(StressFileOut,StrainFile)
 			ECFile = XtalPath + self.xtal + x + '.ecs'
 			np.savetxt(ECFile, EC_Matrix, delimiter='\t')
 			EC_Matrix = EC_Matrix.flatten()
@@ -147,8 +141,6 @@ class Control:
 		AllConstants = AllConstants.reshape([self.count,-1])
 		return AllConstants
 
-
-
 	def Dispersion(self,ECs):
 		CurrentDir = os.getcwd()
 		XtalPath = CurrentDir + os.path.sep + self.xtal + os.path.sep
@@ -191,7 +183,7 @@ class Control:
 		AllFreqs = np.reshape(AllFreqs,(self.count,-1))
 		return AllFreqs
 
-	def QuasiHarmonic(self,Freqs,Vols,Press):
+	def QuasiHarmonic(self,Freqs,Vols,Press,tL):
 		CurrentDir = os.getcwd()
 		XtalPath = CurrentDir + os.path.sep + self.xtal + os.path.sep
 		CurveFile = XtalPath + self.xtal + '.dat'
@@ -199,13 +191,11 @@ class Control:
 		ev_data = EVParams.get_evcurve()
 		Vols = np.double(Vols)
 		if np.size(Vols) == 1:
-			AllData = dos.EvaluateDOS(Freqs,self.atoms)
+			AllData = dos.EvaluateDOS(Freqs,self.atoms,tL)
 		else:
-			AllData = qha2.QHA(Freqs,Vols,ev_data,self.count,self.atoms,Press)
+			AllData = qha2.QHA(Freqs,Vols,ev_data,self.count,self.atoms,Press,tL)
 		return AllData
 		
 	def PhaseTransControl(self,AllData1,AllData2,Press):
 		PhaseTransData = qha2.PhaseTrans(AllData1,AllData2,Press)
-		return PhaseTransData
-		
-	
+		return PhaseTransData
\ No newline at end of file
