@@ -38,6 +38,8 @@ class ReadIFile:
 					p2vol_list = np.append(p2vol_list,line)
 				elif Label == 'Pmax'.lower():
 					Pmax = float(line)
+				elif Label == 'Tmax'.lower():
+					Tmax = float(line)
 				elif Label == 'Blank':
 					continue
 		file.close()
@@ -75,7 +77,7 @@ class ReadIFile:
 			P2atom_array = AtomIDS(P2atom_list)	
 		acoustic_job = AcousticJobID(acoustic_list)
 	
-		return P1atom_array, P2atom_array, xtal_list, acoustic_job, p1vol_list, p2vol_list, Pmax
+		return P1atom_array, P2atom_array, xtal_list, acoustic_job, p1vol_list, p2vol_list, Pmax, Tmax
 
 class ReadYaml:
 	def __init__(self, f):
